==> billogram-foundation-3.11.0.tgz: package/modules/components/datepicker/DatepickerContainer.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import { connect } from 'react-redux';
import invariant from 'invariant';

import actionName from '../../utils/actionName';
import getComponentState from '../../utils/getComponentState';

import datepickerChange from './redux/datepickerChange';
import datepickerCollapse from './redux/datepickerCollapse';
import datepickerExpand from './redux/datepickerExpand';
import datepickerSelectedIndexChange from './redux/datepickerSelectedIndexChange';


const changeType = actionName('CHANGE');
const collapseType = actionName('COLLAPSE');
const expandType = actionName('EXPAND');
const selectedIndexChangeType = actionName('SELECTED-INDEX-CHANGE');

export {
    changeType,
    collapseType,
    expandType,
    selectedIndexChangeType
};

export default ({
    Component
} = {}) => {

    invariant(Component !== undefined, 'Missing Datepicker component.');

    const Container = React.createClass({

        displayName: `${Component.displayName}Container`,

        mixins: [PureRenderMixin],

        propTypes: {
            actionTypePrefix: PropTypes.string,
            customActionMetadata: PropTypes.object,
            path: PropTypes.string,
            root: PropTypes.string
        },

        render() {
            return (
                <Component { ...this.props } />
            );
        }

    });

    const mapStateToProps = (state, props) => {
        const { currentMonth, expanded, selectedIndex, value } = getComponentState(state, props);
        return {
            currentMonth,
            expanded,
            selectedIndex,
            value
        };
    };

    const mapDispatchToProps = (dispatch, props) => {
        const { customActionMetadata: custom, path, root } = props;
        const actionTypePrefix = props.actionTypePrefix || 'DATEPICKER';

        return {
            onChange: (currentMonth, selectedIndex, value) => dispatch(datepickerChange({ currentMonth, custom, path, root, selectedIndex, type: changeType(actionTypePrefix), value })),
            onCollapse: (currentMonth, selectedIndex) => dispatch(datepickerCollapse({ currentMonth, path, root, selectedIndex, type: collapseType(actionTypePrefix) })),
            onExpand: () => dispatch(datepickerExpand({ path, root, type: expandType(actionTypePrefix) })),
            onSelectedIndexChange: (currentMonth, selectedIndex) => dispatch(datepickerSelectedIndexChange({ currentMonth, path, root, selectedIndex, type: selectedIndexChangeType(actionTypePrefix) }))
        };
    };

    return connect(mapStateToProps, mapDispatchToProps)(Container);

};

==> billogram-foundation-3.13.10.tgz: package/modules/components/datepicker/DatepickerContainer.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import { connect } from 'react-redux';
import invariant from 'invariant';

import actionName from '../../utils/actionName';
import getComponentState from '../../utils/getComponentState';

import datepickerChange from './redux/datepickerChange';
import datepickerCollapse from './redux/datepickerCollapse';
import datepickerExpand from './redux/datepickerExpand';
import datepickerSelectedIndexChange from './redux/datepickerSelectedIndexChange';


export const changeType = actionName('CHANGE');
export const collapseType = actionName('COLLAPSE');
export const expandType = actionName('EXPAND');
export const selectedIndexChangeType = actionName('SELECTED-INDEX-CHANGE');

export default ({
    Component
} = {}) => {

    invariant(Component !== undefined, 'Missing Datepicker component.');

    const Container = React.createClass({

        displayName: `${Component.displayName}Container`,

        mixins: [PureRenderMixin],

        propTypes: {
            actionTypePrefix: PropTypes.string,
            customActionMetadata: PropTypes.object,
            path: PropTypes.string,
            root: PropTypes.string
        },

        render() {
            return (
                <Component { ...this.props } />
            );
        }

    });

    const mapDispatchToProps = (dispatch, props) => {
        const { customActionMetadata: custom, path, root } = props;
        const actionTypePrefix = props.actionTypePrefix || 'DATEPICKER';

        return {
            onChange: (currentMonth, selectedIndex, value) => dispatch(datepickerChange({ currentMonth, custom, path, root, selectedIndex, type: changeType(actionTypePrefix), value })),
            onCollapse: (currentMonth, selectedIndex) => dispatch(datepickerCollapse({ currentMonth, path, root, selectedIndex, type: collapseType(actionTypePrefix) })),
            onExpand: () => dispatch(datepickerExpand({ path, root, type: expandType(actionTypePrefix) })),
            onSelectedIndexChange: (currentMonth, selectedIndex) => dispatch(datepickerSelectedIndexChange({ currentMonth, path, root, selectedIndex, type: selectedIndexChangeType(actionTypePrefix) }))
        };
    };

    return connect(getComponentState, mapDispatchToProps)(Container);

};
